==> enterprisemodules-pg_config-0.4.2.tar.gz: enterprisemodules-pg_config-0.4.2/lib/puppet/type/pg_function.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/read_only_property'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/utilities'

#
# Create a new type pg_function.
#
Puppet::Type.newtype(:pg_function) do
  include EasyType
  include Puppet_X::EnterpriseModules::Postgres::Access
  include Puppet_X::EnterpriseModules::Postgres::Utilities
  extend Puppet_X::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
  This resource allows you to manage SQL functions in the Postgres database.

      pg_function { 'testuser.return_some_value( Integer)@localhost':
        ensure  => 'present',
        source => '/vagrant/tests/function.sql',
      }

  This puppet definition ensures that the function `testuser.return_some_value(Integer)` is available
  in the database and that its content matches the content defined in the specified source.

  To decide if the function needs an update, the puppet type compares the content in the database, with
  the content in the source file. This comparison is done insenitive to case, white spacing and used quote's
  (the " or the ` ).#{' '}
#{'  '}
  To ensure detection of differences, your `content` of `source`needs to have the definition in the same order
  that the function `pg_get_functiondef` uses.

  When you have specified `report_errors => true` (which is the default), the type will fail on SQL
  compilation errors.#{' '}


  DOC

  ensurable

  to_get_raw_resources do
    sql_on_all_databases <<-SQL
        select
            p.proname as name,#{' '}
            encode(pg_get_functiondef(p.oid)::bytea, 'hex') as prosrc,
            p.prosecdef as security_definer
        from
            pg_proc p,
            pg_language l
        where l.oid = p.prolang
        and l.lanname != 'internal'
    SQL
  end

  on_create do
    apply
  end

  on_modify do
    apply
  end

  on_destroy do
    [:sql, "drop function #{namespace}.#{function_name}", { :db => db }]
  end

  def pre_run_check
    raise Puppet::Error, 'Only one source or content can be set up' if self[:ensure].to_s != 'absent' && (source && content)
  end

  def apply
    options = { :db => db, :parse => false }
    options[:failonsqlfail] = report_errors
    if content
      statement = content.to_s
    elsif source
      statement = "@#{source}"
    end
    if cwd
      fail "Working directory '#{cwd}' does not exist" unless File.directory?(cwd)

      FileUtils.cd(cwd)
    end
    if statement
      output = sql statement, options
      Puppet.debug(output) if logoutput.to_s == 'true'
    end
    nil
  end

  map_title_to_db(:namespace, :function_name) { /(.+)\.(.+)/ }

  parameter :name
  parameter :function_name
  parameter :db
  parameter :namespace

  parameter :timeout
  parameter :cwd
  parameter :logoutput
  parameter :report_errors

  property  :source
  property  :content
  property  :security_definer
end

==> enterprisemodules-pg_config-0.7.0.tar.gz: enterprisemodules-pg_config-0.7.0/lib/puppet/type/pg_function.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#

require 'pathname'
$LOAD_PATH.unshift(Pathname.new(__FILE__).dirname.parent.parent)
$LOAD_PATH.unshift("#{Pathname.new(__FILE__).dirname.parent.parent.parent.parent}easy_typelib")
require 'easy_type'
require 'easy_type/array_property'
require 'puppet_x/enterprisemodules/postgres/access'
require 'puppet_x/enterprisemodules/postgres/read_only_property'
require 'puppet_x/enterprisemodules/postgres/title_parser'
require 'puppet_x/enterprisemodules/postgres/utilities'

#
# Create a new type pg_function.
#
Puppet::Type.newtype(:pg_function) do
  include EasyType
  include PuppetX::EnterpriseModules::Postgres::Access
  include PuppetX::EnterpriseModules::Postgres::Utilities
  extend PuppetX::EnterpriseModules::Postgres::TitleParser

  desc <<-DOC
  This resource allows you to manage SQL functions in the Postgres database.

      pg_function { 'testuser.return_some_value( Integer)@localhost':
        ensure  => 'present',
        source => '/vagrant/tests/function.sql',
      }

  This puppet definition ensures that the function `testuser.return_some_value(Integer)` is available
  in the database and that its content matches the content defined in the specified source.

  To decide if the function needs an update, the puppet type compares the content in the database, with
  the content in the source file. This comparison is done insenitive to case, white spacing and used quote's
  (the " or the ` ).#{' '}
#{'  '}
  To ensure detection of differences, your `content` of `source`needs to have the definition in the same order
  that the function `pg_get_functiondef` uses.

  When you have specified `report_errors => true` (which is the default), the type will fail on SQL
  compilation errors.#{' '}


  DOC

  ensurable

  to_get_raw_resources do
    sql_on_all_databases <<-SQL
        select
            p.proname as name,#{' '}
            encode(pg_get_functiondef(p.oid)::bytea, 'hex') as prosrc,
            p.prosecdef as security_definer
        from
            pg_proc p,
            pg_language l
        where l.oid = p.prolang
        and l.lanname != 'internal'
    SQL
  end

  on_create do
    apply
  end

  on_modify do
    apply
  end

  on_destroy do
    [:sql, "drop function #{namespace}.#{function_name}", { :db => db }]
  end

  def pre_run_check
    raise Puppet::Error, 'Only one source or content can be set up' if self[:ensure].to_s != 'absent' && (source && content)
  end

  def apply
    options = { :db => db, :parse => false }
    options[:failonsqlfail] = report_errors
    if content
      statement = content.to_s
    elsif source
      statement = "@#{source}"
    end
    if cwd
      fail "Working directory '#{cwd}' does not exist" unless File.directory?(cwd)

      FileUtils.cd(cwd)
    end
    if statement
      output = sql statement, options
      Puppet.debug(output) if logoutput.to_s == 'true'
    end
    nil
  end

  map_title_to_db(:namespace, :function_name) { /(.+)\.(.+)/ }

  parameter :name
  parameter :function_name
  parameter :db
  parameter :namespace

  parameter :timeout
  parameter :cwd
  parameter :logoutput
  parameter :report_errors

  property  :source
  property  :content
  property  :security_definer
end
